@@ -1,40 +1,47 @@
+# -*- coding: utf-8 -*-
+from datetime import date
+from datetime import datetime
+from datetime import timedelta
 from DateTime import DateTime
 from plone.app.event import base
-from plone.app.event.at.content import EventAccessor as ATEventAccessor
 from plone.app.event.base import AnnotationAdapter
-from plone.app.event.base import DEFAULT_END_DELTA
-from plone.app.event.base import DT
-from plone.app.event.base import RET_MODE_ACCESSORS
-from plone.app.event.base import RET_MODE_OBJECTS
 from plone.app.event.base import construct_calendar
 from plone.app.event.base import dates_for_display
 from plone.app.event.base import default_end
+from plone.app.event.base import DEFAULT_END_DELTA
 from plone.app.event.base import default_start
 from plone.app.event.base import default_timezone
+from plone.app.event.base import DT
 from plone.app.event.base import find_context
 from plone.app.event.base import find_event_listing
 from plone.app.event.base import find_ploneroot
 from plone.app.event.base import find_site
 from plone.app.event.base import get_events
 from plone.app.event.base import localized_now
-from plone.app.event.dx.behaviors import EventAccessor as DXEventAccessor
-from plone.app.event.testing import PAEventAT_INTEGRATION_TESTING
-from plone.app.event.testing import PAEventDX_INTEGRATION_TESTING
+from plone.app.event.base import RET_MODE_ACCESSORS
+from plone.app.event.base import RET_MODE_OBJECTS
+from plone.app.event.base import spell_date
 from plone.app.event.testing import PAEvent_INTEGRATION_TESTING
+from plone.app.event.testing import PAEventDX_INTEGRATION_TESTING
+from plone.app.event.testing import set_env_timezone
+from plone.app.event.testing import set_timezone
 from plone.app.event.tests.base_setup import AbstractSampleDataEvents
-from plone.app.event.tests.base_setup import TEST_TIMEZONE
-from plone.app.testing import TEST_USER_ID
 from plone.app.testing import setRoles
+from plone.app.testing import TEST_USER_ID
+from plone.dexterity.utils import createContentInContainer
 from plone.event.interfaces import IEvent
 from plone.event.interfaces import IEventAccessor
+from plone.event.utils import default_timezone as os_default_timezone
 from plone.event.utils import pydt
+from plone.registry.interfaces import IRegistry
 from zope.annotation.interfaces import IAnnotations
+from zope.component import getUtility
 from zope.component.interfaces import ISite
 from zope.interface import directlyProvides
 
-import datetime
 import pytz
-import unittest2 as unittest
+import six
+import unittest
 
 
 class TestBaseModule(unittest.TestCase):
@@ -51,7 +58,7 @@ class TestBaseModule(unittest.TestCase):
 
     def test_default_end(self):
         self.assertEqualDatetime(
-            default_end() - datetime.timedelta(hours=DEFAULT_END_DELTA),
+            default_end() - timedelta(hours=DEFAULT_END_DELTA),
             default_start())
 
     def test_default_start(self):
@@ -63,14 +70,14 @@ class TestBaseModule(unittest.TestCase):
         # TODO: DateTime better shouldn't do this!
         cet = pytz.timezone('CET')
         self.assertEqual(
-            DT(datetime.datetime(2011, 11, 11, 11, 0, 0, tzinfo=cet)),
+            DT(datetime(2011, 11, 11, 11, 0, 0, tzinfo=cet)),
             DateTime('2011/11/11 11:00:00 GMT+1')
         )
 
         # Python dates get converted to a DateTime with timecomponent including
         # a timezone
         self.assertEqual(
-            DT(datetime.date(2011, 11, 11)),
+            DT(date(2011, 11, 11)),
             DateTime('2011/11/11 00:00:00 UTC')
         )
 
@@ -89,7 +96,7 @@ class TestBaseModule(unittest.TestCase):
         # Invalid datetime zones are converted to the portal timezone
         # Testing with no timezone
         self.assertEqual(
-            DT(datetime.datetime(2011, 11, 11, 11, 0, 0)),
+            DT(datetime(2011, 11, 11, 11, 0, 0)),
             DateTime('2011/11/11 11:00:00 UTC')
         )
 
@@ -99,7 +106,7 @@ class TestBaseModule(unittest.TestCase):
             DateTime('2011/11/11 11:00:00 Europe/Vienna')
         )
 
-        ## TEST WITH/WITHOUT MICROSECONDS
+        # TEST WITH/WITHOUT MICROSECONDS
 
         # From Python datetime
 
@@ -107,14 +114,14 @@ class TestBaseModule(unittest.TestCase):
 
         # exact=False
         self.assertEqual(
-            DT(datetime.datetime(2012, 12, 12, 10, 10, 10, 123456,
+            DT(datetime(2012, 12, 12, 10, 10, 10, 123456,
                tzinfo=tz), exact=False),
             DateTime('2012/12/12 10:10:10 Europe/Vienna')
         )
 
         # exact=True
         self.assertEqual(
-            DT(datetime.datetime(2012, 12, 12, 10, 10, 10, 123456,
+            DT(datetime(2012, 12, 12, 10, 10, 10, 123456,
                tzinfo=tz), exact=True),
             DateTime('2012/12/12 10:10:10.123456 Europe/Vienna')
         )
@@ -155,23 +162,23 @@ class TestBaseModule(unittest.TestCase):
     def test__dt_start_of_day(self):
         from plone.app.event.base import dt_start_of_day
         self.assertEqual(
-            dt_start_of_day(datetime.datetime(2013, 2, 1, 18, 35)),
-            datetime.datetime(2013, 2, 1, 0, 0, 0, 0)
+            dt_start_of_day(datetime(2013, 2, 1, 18, 35)),
+            datetime(2013, 2, 1, 0, 0, 0, 0)
         )
         self.assertEqual(
-            dt_start_of_day(datetime.date(2013, 2, 1)),
-            datetime.datetime(2013, 2, 1, 0, 0, 0, 0)
+            dt_start_of_day(date(2013, 2, 1)),
+            datetime(2013, 2, 1, 0, 0, 0, 0)
         )
 
     def test__dt_end_of_day(self):
         from plone.app.event.base import dt_end_of_day
         self.assertEqual(
-            dt_end_of_day(datetime.datetime(2013, 2, 1, 18, 35)),
-            datetime.datetime(2013, 2, 1, 23, 59, 59, 0)
+            dt_end_of_day(datetime(2013, 2, 1, 18, 35)),
+            datetime(2013, 2, 1, 23, 59, 59, 0)
         )
         self.assertEqual(
-            dt_end_of_day(datetime.date(2013, 2, 1)),
-            datetime.datetime(2013, 2, 1, 23, 59, 59, 0)
+            dt_end_of_day(date(2013, 2, 1)),
+            datetime(2013, 2, 1, 23, 59, 59, 0)
         )
 
     def test__start_end_from_mode(self):
@@ -186,19 +193,19 @@ class TestBaseModule(unittest.TestCase):
         # PAST
         #
         start, end = start_end_from_mode('past')
-        self.assertTrue(start is None and isinstance(end, datetime.datetime))
+        self.assertTrue(start is None and isinstance(end, datetime))
 
         # FUTURE
         #
         start, end = start_end_from_mode('future')
-        self.assertTrue(isinstance(start, datetime.datetime) and end is None)
+        self.assertTrue(isinstance(start, datetime) and end is None)
 
         # NOW
         #
         start, end = start_end_from_mode('now')
         self.assertTrue(
-            isinstance(start, datetime.datetime) and
-            isinstance(end, datetime.datetime) and
+            isinstance(start, datetime) and
+            isinstance(end, datetime) and
             end.hour == 23 and end.minute == 59 and end.second == 59
         )
 
@@ -206,17 +213,17 @@ class TestBaseModule(unittest.TestCase):
         #
         start, end = start_end_from_mode('7days')
         self.assertTrue(
-            isinstance(start, datetime.datetime) and
-            isinstance(end, datetime.datetime) and
-            end == dt_end_of_day(start + datetime.timedelta(days=6))
+            isinstance(start, datetime) and
+            isinstance(end, datetime) and
+            end == dt_end_of_day(start + timedelta(days=6))
         )
 
         # TODAY
         #
         start, end = start_end_from_mode('today')
         self.assertTrue(
-            isinstance(start, datetime.datetime) and
-            isinstance(end, datetime.datetime) and
+            isinstance(start, datetime) and
+            isinstance(end, datetime) and
             start.hour == 0 and start.minute == 0 and start.second == 0 and
             end.hour == 23 and end.minute == 59 and end.second == 59 and
             (start, end) == start_end_from_mode('day')
@@ -224,7 +231,7 @@ class TestBaseModule(unittest.TestCase):
 
         # DAY
         #
-        day = datetime.datetime(2013, 2, 1, 18, 22)
+        day = datetime(2013, 2, 1, 18, 22)
         start, end = start_end_from_mode('day', day)
         self.assertTrue(
             start.date() == day.date() == end.date() and
@@ -233,7 +240,7 @@ class TestBaseModule(unittest.TestCase):
         )
 
         # test with date-only
-        day = datetime.datetime(2013, 2, 1)
+        day = datetime(2013, 2, 1)
         start, end = start_end_from_mode('day', day)
         self.assertTrue(
             start.date() == day.date() == end.date() and
@@ -256,7 +263,7 @@ class TestBaseModule(unittest.TestCase):
         orig_first_weekday = base.first_weekday
 
         base.first_weekday = ret_0
-        day = datetime.datetime(2013, 2, 2)
+        day = datetime(2013, 2, 2)
         start, end = start_end_from_mode('week', day)
         self.assertTrue(
             start.isoformat() == '2013-01-28T00:00:00' and
@@ -264,7 +271,7 @@ class TestBaseModule(unittest.TestCase):
         )
 
         base.first_weekday = ret_1
-        day = datetime.datetime(2013, 2, 2)
+        day = datetime(2013, 2, 2)
         start, end = start_end_from_mode('week', day)
         self.assertTrue(
             start.isoformat() == '2013-01-29T00:00:00' and
@@ -272,7 +279,7 @@ class TestBaseModule(unittest.TestCase):
         )
 
         base.first_weekday = ret_6
-        day = datetime.datetime(2013, 2, 1)
+        day = datetime(2013, 2, 1)
         start, end = start_end_from_mode('week', day)
         self.assertTrue(
             start.isoformat() == '2013-01-27T00:00:00' and
@@ -286,7 +293,7 @@ class TestBaseModule(unittest.TestCase):
         start, end = start_end_from_mode('month')
         self.assertTrue(start < end and start.day == 1)
 
-        day = datetime.datetime(2013, 2, 7)
+        day = datetime(2013, 2, 7)
         start, end = start_end_from_mode('month', day)
         self.assertTrue(
             start.year == 2013 and start.month == 2 and start.day == 1 and
@@ -295,6 +302,46 @@ class TestBaseModule(unittest.TestCase):
             end.hour == 23 and end.minute == 59 and end.second == 59
         )
 
+    def test_spell_date(self):
+        DT = DateTime(2015, 6, 6, 1, 2, 3)
+        date_spelled = spell_date(DT, self.portal)
+        self.assertEqual(date_spelled['year'], 2015)
+        self.assertEqual(date_spelled['month'], 6)
+        self.assertEqual(date_spelled['month2'], '06')
+        self.assertEqual(date_spelled['day'], 6)
+        self.assertEqual(date_spelled['day2'], '06')
+        self.assertEqual(date_spelled['hour'], 1)
+        self.assertEqual(date_spelled['hour2'], '01')
+        self.assertEqual(date_spelled['minute'], 2)
+        self.assertEqual(date_spelled['minute2'], '02')
+        self.assertEqual(date_spelled['second'], 3)
+        self.assertEqual(date_spelled['second2'], '03')
+        self.assertEqual(date_spelled['week'], 23)
+
+        # locale specific
+        # TODO: test better.
+        self.assertTrue(isinstance(date_spelled['wkday'], int))
+        self.assertTrue(isinstance(date_spelled['month_name'], six.string_types))
+        self.assertTrue(isinstance(date_spelled['month_abbr'], six.string_types))
+        self.assertTrue(isinstance(date_spelled['wkday_name'], six.string_types))
+        self.assertTrue(isinstance(date_spelled['wkday_abbr'], six.string_types))
+
+
+class TimezoneTest(unittest.TestCase):
+    layer = PAEvent_INTEGRATION_TESTING
+
+    def setUp(self):
+        self.portal = self.layer['portal']
+        set_env_timezone('UTC')
+        set_timezone('UTC')
+
+    def test_default_timezone(self):
+        self.assertTrue(os_default_timezone() == default_timezone() == 'UTC')
+
+        registry = getUtility(IRegistry)
+        registry['plone.portal_timezone'] = "Europe/Vienna"
+        self.assertTrue(default_timezone() == 'Europe/Vienna')
+
 
 class TestAnnotationAdapter(unittest.TestCase):
     layer = PAEvent_INTEGRATION_TESTING
@@ -393,10 +440,6 @@ class TestGetEventsDX(AbstractSampleDataEvents):
     """
     layer = PAEventDX_INTEGRATION_TESTING
 
-    def event_factory(self):
-        DXEventAccessor.portal_type = 'plone.app.event.dx.event'
-        return DXEventAccessor.create
-
     def test_get_events(self):
 
         # whole range
@@ -528,18 +571,18 @@ class TestGetEventsDX(AbstractSampleDataEvents):
         be done after expanding the occurrences. Then we really have the
         correct order.
         """
-        factory = self.event_factory()
+        factory = self.event_factory
         factory(
             container=self.portal,
-            content_id='past_recur1',
-            title=u'Past Event recurring 1',
+            content_id='past_recur',
+            title=u'Past Event recurring',
             start=self.past,
             end=self.past + self.duration,
             location=u"Dornbirn",
-            timezone=TEST_TIMEZONE,
             recurrence='RRULE:FREQ=WEEKLY;COUNT=4',
         )
-        factory(
+
+        tomorrow = factory(
             container=self.portal,
             content_id='tomorrow',
             title=u'Tomorrow event',
@@ -547,8 +590,8 @@ class TestGetEventsDX(AbstractSampleDataEvents):
             end=self.tomorrow + self.duration,
             open_end=True,
             location=u"Dornbirn",
-            timezone=TEST_TIMEZONE,
         )
+        tomorrow.reindexObject()
 
         limit = get_events(self.portal, start=self.now, expand=True,
                            ret_mode=RET_MODE_ACCESSORS, limit=3)
@@ -576,25 +619,27 @@ class TestGetEventsDX(AbstractSampleDataEvents):
         # Completly outside range and start, end given as datetime
         cal = construct_calendar(
             res,
-            start=datetime.datetime(2000, 1, 1, 10, 0),
-            end=datetime.datetime(2000, 1, 2, 10, 0)
+            start=datetime(2000, 1, 1, 10, 0),
+            end=datetime(2000, 1, 2, 10, 0)
         )
         self.assertEqual(_num_events(cal.values()), 0)
 
         # Within range
         cal = construct_calendar(
             res,
-            start=datetime.date(2013, 5, 1),
-            end=datetime.date(2013, 5, 31)
+            start=date(2013, 5, 1),
+            end=date(2013, 5, 31)
         )
-        self.assertEqual(_num_events(cal.values()), 34)
+        self.assertEqual(_num_events(cal.values()), 35)
+        # First day must also be set in the calendar
+        self.assertTrue('2013-05-01' in cal.keys())
 
         # invalid start
         def _invalid_start():
             return construct_calendar(
                 res,
                 start='invalid',
-                end=datetime.datetime(2000, 1, 2, 10, 0)
+                end=datetime(2000, 1, 2, 10, 0)
             )
 
         self.assertRaises(AssertionError, _invalid_start)
@@ -603,37 +648,12 @@ class TestGetEventsDX(AbstractSampleDataEvents):
         def _invalid_end():
             return construct_calendar(
                 res,
-                start=datetime.datetime(2000, 1, 1, 10, 0),
+                start=datetime(2000, 1, 1, 10, 0),
                 end='invalid'
             )
         self.assertRaises(AssertionError, _invalid_end)
 
 
-class TestGetEventsATPydt(TestGetEventsDX):
-    """Test get_events with AT objects and datetime based dates.
-    """
-    layer = PAEventAT_INTEGRATION_TESTING
-
-    def event_factory(self):
-        return ATEventAccessor.create
-
-
-class TestGetEventsATZDT(TestGetEventsATPydt):
-    """Test get_events with AT objects and Zope DateTime based dates.
-    """
-    layer = PAEventAT_INTEGRATION_TESTING
-
-    def make_dates(self):
-        def_tz = default_timezone()
-        now = self.now = DateTime(2013, 5, 5, 10, 0, 0, def_tz)
-        self.tomorrow = DateTime(2013, 5, 6, 10, 0, 0, def_tz)
-        past = self.past = DateTime(2013, 4, 25, 10, 0, 0, def_tz)
-        future = self.future = DateTime(2013, 5, 15, 10, 0, 0, def_tz)
-        far = self.far = DateTime(2013, 6, 4, 10, 0, 0, def_tz)
-        duration = self.duration = 0.1
-        return (now, past, future, far, duration)
-
-
 class TestGetEventsOptimizations(AbstractSampleDataEvents):
     """Test get_events performance optimizations
 
@@ -643,15 +663,11 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
     """
     layer = PAEventDX_INTEGRATION_TESTING
 
-    def event_factory(self):
-        DXEventAccessor.portal_type = 'plone.app.event.dx.event'
-        return DXEventAccessor.create
-
     def setUp(self):
         AbstractSampleDataEvents.setUp(self)
 
         # add extra events to the base setup
-        factory = self.event_factory()
+        factory = self.event_factory
         factory(
             container=self.portal,
             content_id='past_recur',
@@ -659,10 +675,10 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
             start=self.past + self.duration,
             end=self.past + self.duration + self.duration,
             location=u"Dornbirn",
-            timezone=TEST_TIMEZONE,
             recurrence='RRULE:FREQ=WEEKLY;COUNT=4',
         )
-        factory(
+
+        tomorrow = factory(
             container=self.portal,
             content_id='tomorrow',
             title=u'Tomorrow event',
@@ -670,8 +686,9 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
             end=self.tomorrow + self.duration,
             open_end=True,
             location=u"Dornbirn",
-            timezone=TEST_TIMEZONE,
         )
+        tomorrow.reindexObject()
+
         self.occ = [
             (u'Past Event', '2013-04-25 00:00:00', '2013-04-25 23:59:59'),
             (u'Long Event', '2013-04-25 10:00:00', '2013-06-04 10:00:00'),
@@ -698,7 +715,7 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
                  x.end.strftime('%Y-%m-%d %H:%M:%S'))
                 for x in seq]
 
-    ### expand=True: events
+    # expand=True: events
 
     def test_expand_all(self):
         # all occurrences, sorted by start
@@ -730,7 +747,7 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
         expect = self.occ[1:2] + self.occ[6:8]  # includes ongoing long event
         self.assertEqual(res, expect, self.diff(res, expect))
 
-    ### expand=False: events
+    # expand=False: events
 
     def test_noexpand_all(self):
         # all events
@@ -811,89 +828,7 @@ class TestGetEventsOptimizations(AbstractSampleDataEvents):
         self.assertEqual(res, expect[:3], self.diff(res, expect[:3]))
 
 
-class TestDatesForDisplayAT(unittest.TestCase):
-    layer = PAEventAT_INTEGRATION_TESTING
-
-    def setUp(self):
-        self.portal = self.layer['portal']
-        setRoles(self.portal, TEST_USER_ID, ['Manager'])
-
-    def test_prep_display_with_time(self):
-        event_id = self.portal.invokeFactory(
-            'Event',
-            id="event",
-            startDate='2000/10/12 06:00:00',
-            endDate='2000/10/12 18:00:00',
-            timezone="Europe/Vienna"
-        )
-        event = self.portal[event_id]
-        self.assertEqual(
-            dates_for_display(event),
-            {'start_date': u'Oct 12, 2000',
-             'start_time': u'06:00 AM',
-             'start_iso':  '2000-10-12T06:00:00+02:00',
-             'end_date':   u'Oct 12, 2000',
-             'end_time':   u'06:00 PM',
-             'end_iso':    '2000-10-12T18:00:00+02:00',
-             'same_day':   True,
-             'same_time':  False,
-             'whole_day':  False,
-             'open_end':   False,
-             }
-        )
-
-    def test_prep_display_wholeday_sameday(self):
-        event_id = self.portal.invokeFactory(
-            'Event',
-            id="event",
-            startDate='2000/10/12 06:00:00',
-            endDate='2000/10/12 18:00:00',
-            timezone="Europe/Vienna",
-            wholeDay=True
-        )
-        event = self.portal[event_id]
-        self.assertEqual(
-            dates_for_display(event),
-            {'start_date': u'Oct 12, 2000',
-             'start_time': None,
-             'start_iso':  '2000-10-12',
-             'end_date':   u'Oct 12, 2000',
-             'end_time':   None,
-             'end_iso':    '2000-10-12',
-             'same_day':   True,
-             'same_time':  False,
-             'whole_day':  True,
-             'open_end':   False
-             }
-        )
-
-    def test_prep_display_wholeday_differentdays(self):
-        event_id = self.portal.invokeFactory(
-            'Event',
-            id="event",
-            startDate='2000/10/12 06:00:00',
-            endDate='2000/10/13 18:00:00',
-            timezone="Europe/Vienna",
-            wholeDay=True
-        )
-        event = self.portal[event_id]
-        self.assertEqual(
-            dates_for_display(event),
-            {'start_date': u'Oct 12, 2000',
-             'start_time': None,
-             'start_iso':  '2000-10-12',
-             'end_date':   u'Oct 13, 2000',
-             'end_time':   None,
-             'end_iso':    '2000-10-13',
-             'same_day':   False,
-             'same_time':  False,
-             'whole_day':  True,
-             'open_end':   False,
-             }
-        )
-
-
-class TestDatesForDisplayDX(unittest.TestCase):
+class TestDatesForDisplay(unittest.TestCase):
     layer = PAEventDX_INTEGRATION_TESTING
 
     def setUp(self):
@@ -901,79 +836,75 @@ class TestDatesForDisplayDX(unittest.TestCase):
         setRoles(self.portal, TEST_USER_ID, ['Manager'])
 
     def test_prep_display_with_time(self):
-        event_id = self.portal.invokeFactory(
+        tz = pytz.timezone("Europe/Vienna")
+        event = createContentInContainer(
+            self.portal,
             'plone.app.event.dx.event',
             id="event",
-            start=datetime.datetime(2000, 10, 12, 6, 0, 0),
-            end=datetime.datetime(2000, 10, 12, 18, 0, 0),
-            timezone="Europe/Vienna",
-            whole_day=False,
-            open_end=False
+            start=tz.localize(datetime(2000, 10, 12, 6, 0, 0)),
+            end=tz.localize(datetime(2000, 10, 12, 18, 0, 0))
         )
-        event = self.portal[event_id]
         self.assertEqual(
             dates_for_display(event),
             {'start_date': u'Oct 12, 2000',
              'start_time': u'06:00 AM',
-             'start_iso':  '2000-10-12T06:00:00+02:00',
-             'end_date':   u'Oct 12, 2000',
-             'end_time':   u'06:00 PM',
-             'end_iso':    '2000-10-12T18:00:00+02:00',
-             'same_day':   True,
-             'same_time':  False,
-             'whole_day':  False,
-             'open_end':   False,
+             'start_iso': '2000-10-12T06:00:00+02:00',
+             'end_date': u'Oct 12, 2000',
+             'end_time': u'06:00 PM',
+             'end_iso': '2000-10-12T18:00:00+02:00',
+             'same_day': True,
+             'same_time': False,
+             'whole_day': False,
+             'open_end': False,
              }
         )
 
     def test_prep_display_wholeday_sameday(self):
-        event_id = self.portal.invokeFactory(
+        tz = pytz.timezone("Europe/Vienna")
+        event = createContentInContainer(
+            self.portal,
             'plone.app.event.dx.event',
             id="event",
-            start=datetime.datetime(2000, 10, 12, 6, 0, 0),
-            end=datetime.datetime(2000, 10, 12, 18, 0, 0),
-            timezone="Europe/Vienna",
-            whole_day=True,
-            open_end=False
+            start=tz.localize(datetime(2000, 10, 12, 0, 0, 0)),
+            end=tz.localize(datetime(2000, 10, 12, 23, 59, 59)),
+            whole_day=True
         )
-        event = self.portal[event_id]
         self.assertEqual(
             dates_for_display(event),
             {'start_date': u'Oct 12, 2000',
              'start_time': None,
-             'start_iso':  '2000-10-12',
-             'end_date':   u'Oct 12, 2000',
-             'end_time':   None,
-             'end_iso':    '2000-10-12',
-             'same_day':   True,
-             'same_time':  False,
-             'whole_day':  True,
-             'open_end':   False,
+             'start_iso': '2000-10-12',
+             'end_date': u'Oct 12, 2000',
+             'end_time': None,
+             'end_iso': '2000-10-12',
+             'same_day': True,
+             'same_time': False,
+             'whole_day': True,
+             'open_end': False,
              }
         )
 
     def test_prep_display_wholeday_differentdays(self):
-        event_id = self.portal.invokeFactory(
+        tz = pytz.timezone("Europe/Vienna")
+        event = createContentInContainer(
+            self.portal,
             'plone.app.event.dx.event',
             id="event",
-            start=datetime.datetime(2000, 10, 12, 6, 0, 0),
-            end=datetime.datetime(2000, 10, 13, 18, 0, 0),
-            timezone="Europe/Vienna",
-            whole_day=True,
-            open_end=False
+            start=tz.localize(datetime(2000, 10, 12, 0, 0, 0)),
+            end=tz.localize(datetime(2000, 10, 13, 23, 59, 59)),
+            whole_day=True
         )
-        event = self.portal[event_id]
         self.assertEqual(
             dates_for_display(event),
             {'start_date': u'Oct 12, 2000',
              'start_time': None,
-             'start_iso':  '2000-10-12',
-             'end_date':   u'Oct 13, 2000',
-             'end_time':   None,
-             'end_iso':    '2000-10-13',
-             'same_day':   False,
-             'same_time':  False,
-             'whole_day':  True,
-             'open_end':   False,
+             'start_iso': '2000-10-12',
+             'end_date': u'Oct 13, 2000',
+             'end_time': None,
+             'end_iso': '2000-10-13',
+             'same_day': False,
+             'same_time': False,
+             'whole_day': True,
+             'open_end': False,
              }
         )
