@@ -1,26 +1,21 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 from plone.app.event import base
-from plone.app.event.at.content import EventAccessor as ATEventAccessor
-from plone.app.event.at.traverser import OccurrenceTraverser as OccTravAT
-from plone.app.event.dx.behaviors import EventAccessor as DXEventAccessor
 from plone.app.event.dx.traverser import OccurrenceTraverser as OccTravDX
 from plone.app.event.ical.importer import ical_import
-from plone.app.event.testing import PAEventAT_INTEGRATION_TESTING
-from plone.app.event.testing import PAEventAT_FUNCTIONAL_TESTING
-from plone.app.event.testing import PAEventDX_INTEGRATION_TESTING
-from plone.app.event.testing import PAEventDX_FUNCTIONAL_TESTING
 from plone.app.event.testing import make_fake_response
+from plone.app.event.testing import PAEventDX_FUNCTIONAL_TESTING
+from plone.app.event.testing import PAEventDX_INTEGRATION_TESTING
 from plone.app.event.tests.base_setup import AbstractSampleDataEvents
-from plone.app.testing import TEST_USER_ID
 from plone.app.testing import setRoles
+from plone.app.testing import TEST_USER_ID
 from plone.event.interfaces import IEventAccessor
-from plone.event.utils import pydt
 from zope.component import getMultiAdapter
 
 import os
 import pytz
-import unittest2 as unittest
+import six
+import unittest
 
 
 # TODO:
@@ -32,10 +27,6 @@ import unittest2 as unittest
 class ICalendarExportTestDX(AbstractSampleDataEvents):
     layer = PAEventDX_INTEGRATION_TESTING
 
-    def event_factory(self):
-        DXEventAccessor.portal_type = 'plone.app.event.dx.event'
-        return DXEventAccessor.create
-
     def traverser(self, context, request):
         return OccTravDX(context, request)
 
@@ -52,10 +43,12 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
         headers, output, request = make_fake_response(self.request)
         view = getMultiAdapter((self.now_event, request), name='ics_view')
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
-
         self.checkOrder(
             icalstr,
             'BEGIN:VCALENDAR',
@@ -71,10 +64,8 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
             'RRULE:FREQ=DAILY;COUNT=3;INTERVAL=1',
             'RDATE;TZID=Europe/Vienna:20130509T000000',
             'EXDATE;TZID=Europe/Vienna:20130506T000000,20140404T000000',
-            'CATEGORIES:plone',
-            'CATEGORIES:testing',
-            'CONTACT:Auto Testdriver\\, +123456789\\, testdriver@plone.org\\, '
-            'http://plone',  # continuation of line above
+            'CATEGORIES:plone,testing',
+            'CONTACT:Auto Testdriver\\, +123456789\\, testdriver@plone.org\\, http://plone',  # noqa
             ' .org',  # line longer than max length spec by icalendar
             'CREATED;VALUE=DATE-TIME:',
             'LAST-MODIFIED;VALUE=DATE-TIME:',
@@ -103,8 +94,11 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
         )
         view = getMultiAdapter((occ, request), name='ics_view')
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
         self.assertTrue('Now Event' in icalstr)
         self.assertTrue('RRULE' not in icalstr)
@@ -113,13 +107,15 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
         headers, output, request = make_fake_response(self.request)
         view = getMultiAdapter((self.portal, request), name='ics_view')
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
 
         # No occurrences in export. Otherwise count would be 8.
         self.assertEqual(icalstr.count('BEGIN:VEVENT'), 4)
-
         self.checkOrder(
             icalstr,
             'BEGIN:VCALENDAR',
@@ -161,10 +157,8 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
             'RRULE:FREQ=DAILY;COUNT=3;INTERVAL=1',
             'RDATE;TZID=Europe/Vienna:20130509T000000',
             'EXDATE;TZID=Europe/Vienna:20130506T000000,20140404T000000',
-            'CATEGORIES:plone',
-            'CATEGORIES:testing',
-            'CONTACT:Auto Testdriver\\, +123456789\\, testdriver@plone.org\\, '
-            'http://plone',  # continuation of line above
+            'CATEGORIES:plone,testing',
+            'CONTACT:Auto Testdriver\\, +123456789\\, testdriver@plone.org\\, http://plone',  # noqa
             ' .org',
             'CREATED;VALUE=DATE-TIME:',
             'LAST-MODIFIED;VALUE=DATE-TIME:',
@@ -207,8 +201,11 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
         )
         view.mode = 'all'
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
         # No occurrences in export. Otherwise count would be 8.
         self.assertEqual(icalstr.count('BEGIN:VEVENT'), 4)
@@ -225,15 +222,18 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
         view.mode = 'day'
         view._date = '2013-04-27'
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
         self.assertEqual(icalstr.count('BEGIN:VEVENT'), 2)
         self.assertTrue('Past Event' in icalstr)
         self.assertTrue('Long Event' in icalstr)
 
     def test_collection_ical(self):
-        """Test basic icalendar export from ATTopics.
+        """Test basic icalendar export from Collections.
         """
         headers, output, request = make_fake_response(self.request)
         view = getMultiAdapter(
@@ -241,20 +241,37 @@ class ICalendarExportTestDX(AbstractSampleDataEvents):
             name='ics_view'
         )
         view()
-        self.assertEqual(len(headers), 2)
+        self.assertEqual(len(headers), 3)
         self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
         icalstr = ''.join(output)
         self.assertEqual(icalstr.count('BEGIN:VEVENT'), 4)
 
-
-class ICalendarExportTestAT(ICalendarExportTestDX):
-    layer = PAEventAT_INTEGRATION_TESTING
-
-    def event_factory(self):
-        return ATEventAccessor.create
-
-    def traverser(self, context, request):
-        return OccTravAT(context, request)
+    def test_collection_all_ical(self):
+        """Test basic icalendar export from Collections, which returns not only
+        events.
+        """
+        headers, output, request = make_fake_response(self.request)
+        self.portal.collection.query = [
+            {'i': 'portal_type',
+             'o': 'plone.app.querystring.operation.selection.any',
+             'v': ['Event', 'plone.app.event.dx.event', 'Page']
+             },
+        ]
+        view = getMultiAdapter(
+            (self.portal.collection, request),
+            name='ics_view'
+        )
+        view()
+        self.assertEqual(len(headers), 3)
+        self.assertEqual(headers['Content-Type'], 'text/calendar')
+        self.assertTrue('Content-Length' in headers)
+        if six.PY3:
+            output = [i.decode('utf8') for i in output]
+        icalstr = ''.join(output)
+        self.assertEqual(icalstr.count('BEGIN:VEVENT'), 4)
 
 
 class TestIcalImportDX(unittest.TestCase):
@@ -272,8 +289,9 @@ class TestIcalImportDX(unittest.TestCase):
         impfolder = self.portal.impfolder1
 
         directory = os.path.dirname(__file__)
-        icsfile = open(os.path.join(directory, 'icaltest.ics'), 'rb').read()
-        res = ical_import(impfolder, icsfile, self.event_type)
+        with open(os.path.join(directory, 'icaltest.ics'), 'rb') as icsfile:
+            icsdata = icsfile.read()
+        res = ical_import(impfolder, icsdata, self.event_type)
 
         self.assertEqual(res['count'], 5)
         self.assertEqual(len(impfolder.contentIds()), 5)
@@ -288,11 +306,11 @@ class TestIcalImportDX(unittest.TestCase):
         e1 = IEventAccessor(impfolder.e1)
         self.assertEqual(
             e1.start,
-            pydt(datetime(2013, 7, 19, 12, 0, tzinfo=at))
+            at.localize(datetime(2013, 7, 19, 12, 0))
         )
         self.assertEqual(
             e1.end,
-            pydt(datetime(2013, 7, 20, 13, 0, tzinfo=at))
+            at.localize(datetime(2013, 7, 20, 13, 0))
         )
         self.assertEqual(
             e1.description,
@@ -314,11 +332,11 @@ class TestIcalImportDX(unittest.TestCase):
         e2 = IEventAccessor(impfolder.e2)
         self.assertEqual(
             e2.start,
-            pydt(datetime(1996, 4, 1, 1, 0, tzinfo=utc))
+            utc.localize(datetime(1996, 4, 1, 1, 0))
         )
         self.assertEqual(
             e2.end,
-            pydt(datetime(1996, 4, 1, 2, 0, tzinfo=utc))
+            utc.localize(datetime(1996, 4, 1, 2, 0))
         )
         self.assertEqual(
             e2.recurrence,
@@ -329,11 +347,11 @@ class TestIcalImportDX(unittest.TestCase):
         e3 = IEventAccessor(impfolder.e3)
         self.assertEqual(
             e3.start,
-            pydt(datetime(2012, 3, 27, 10, 0, tzinfo=at))
+            at.localize(datetime(2012, 3, 27, 10, 0))
         )
         self.assertEqual(
             e3.end,
-            pydt(datetime(2012, 3, 27, 18, 0, tzinfo=at))
+            at.localize(datetime(2012, 3, 27, 18, 0))
         )
         self.assertEqual(
             e3.recurrence,
@@ -345,11 +363,11 @@ class TestIcalImportDX(unittest.TestCase):
         e4 = IEventAccessor(impfolder.e4)
         self.assertEqual(
             e4.start,
-            pydt(datetime(2013, 4, 4, 0, 0, tzinfo=utc))
+            utc.localize(datetime(2013, 4, 4, 0, 0))
         )
         self.assertEqual(
             e4.end,
-            pydt(datetime(2013, 4, 4, 23, 59, 59, tzinfo=utc))
+            utc.localize(datetime(2013, 4, 4, 23, 59, 59))
         )
         self.assertEqual(
             e4.whole_day,
@@ -363,11 +381,11 @@ class TestIcalImportDX(unittest.TestCase):
         e5 = IEventAccessor(impfolder.e5)
         self.assertEqual(
             e5.start,
-            pydt(datetime(2013, 4, 2, 12, 0, tzinfo=utc))
+            utc.localize(datetime(2013, 4, 2, 12, 0))
         )
         self.assertEqual(
             e5.end,
-            pydt(datetime(2013, 4, 2, 23, 59, 59, tzinfo=utc))
+            utc.localize(datetime(2013, 4, 2, 23, 59, 59))
         )
         self.assertEqual(
             e5.whole_day,
@@ -386,15 +404,17 @@ class TestIcalImportDX(unittest.TestCase):
         impfolder = self.portal.impfolder2
 
         directory = os.path.dirname(__file__)
-        icsfile = open(os.path.join(directory, 'icaltest.ics'), 'rb').read()
+        with open(os.path.join(directory, 'icaltest.ics'), 'rb') as icsfile:
+            icsdata = icsfile.read()
+
+        res = ical_import(impfolder, icsdata, self.event_type)
 
-        res = ical_import(impfolder, icsfile, self.event_type)
         self.assertEqual(res['count'], 5)
 
         e11 = impfolder['e1']
         suid1 = IEventAccessor(e11).sync_uid
 
-        res = ical_import(impfolder, icsfile, self.event_type,
+        res = ical_import(impfolder, icsdata, self.event_type,
                           sync_strategy=base.SYNC_NONE)
         self.assertEqual(res['count'], 5)
 
@@ -411,16 +431,17 @@ class TestIcalImportDX(unittest.TestCase):
         impfolder = self.portal.impfolder3
 
         directory = os.path.dirname(__file__)
-        icsfile = open(os.path.join(directory, 'icaltest.ics'), 'rb').read()
+        with open(os.path.join(directory, 'icaltest.ics'), 'rb') as icsfile:
+            icsdata = icsfile.read()
 
-        res = ical_import(impfolder, icsfile, self.event_type)
+        res = ical_import(impfolder, icsdata, self.event_type)
         self.assertEqual(res['count'], 5)
 
         e1a = IEventAccessor(impfolder.e1)
         mod1 = e1a.last_modified
         suid1 = e1a.sync_uid
 
-        res = ical_import(impfolder, icsfile, self.event_type,
+        res = ical_import(impfolder, icsdata, self.event_type,
                           sync_strategy=base.SYNC_KEEP_MINE)
         self.assertEqual(res['count'], 0)
         e1a = IEventAccessor(impfolder.e1)
@@ -440,10 +461,13 @@ class TestIcalImportDX(unittest.TestCase):
         impfolder = self.portal.impfolder4
 
         directory = os.path.dirname(__file__)
-        icsfile = open(os.path.join(directory, 'icaltest.ics'), 'rb').read()
-        icsfile2 = open(os.path.join(directory, 'icaltest2.ics'), 'rb').read()
+        with open(os.path.join(directory, 'icaltest.ics'), 'rb') as icsfile:
+            icsdata1 = icsfile.read()
 
-        res = ical_import(impfolder, icsfile, self.event_type)
+        with open(os.path.join(directory, 'icaltest2.ics'), 'rb') as icsfile:
+            icsdata2 = icsfile.read()
+
+        res = ical_import(impfolder, icsdata1, self.event_type)
         self.assertEqual(res['count'], 5)
 
         e1a = IEventAccessor(impfolder.e1)
@@ -454,7 +478,7 @@ class TestIcalImportDX(unittest.TestCase):
         start1 = e1a.start
         end1 = e1a.end
 
-        res = ical_import(impfolder, icsfile2, self.event_type,
+        res = ical_import(impfolder, icsdata2, self.event_type,
                           sync_strategy=base.SYNC_KEEP_NEWER)
         self.assertEqual(res['count'], 4)
         e1a = IEventAccessor(impfolder.e1)
@@ -482,10 +506,14 @@ class TestIcalImportDX(unittest.TestCase):
         impfolder = self.portal.impfolder5
 
         directory = os.path.dirname(__file__)
-        icsfile = open(os.path.join(directory, 'icaltest.ics'), 'rb').read()
-        icsfile2 = open(os.path.join(directory, 'icaltest2.ics'), 'rb').read()
 
-        res = ical_import(impfolder, icsfile, self.event_type)
+        with open(os.path.join(directory, 'icaltest.ics'), 'rb') as icsfile:
+            icsdata1 = icsfile.read()
+
+        with open(os.path.join(directory, 'icaltest2.ics'), 'rb') as icsfile:
+            icsdata2 = icsfile.read()
+
+        res = ical_import(impfolder, icsdata1, self.event_type)
         self.assertEqual(res['count'], 5)
 
         e1a = IEventAccessor(impfolder.e1)
@@ -503,7 +531,7 @@ class TestIcalImportDX(unittest.TestCase):
         start21 = e2a.start
         end21 = e2a.end
 
-        res = ical_import(impfolder, icsfile2, self.event_type,
+        res = ical_import(impfolder, icsdata2, self.event_type,
                           sync_strategy=base.SYNC_KEEP_THEIRS)
         self.assertEqual(res['count'], 5)
 
@@ -536,8 +564,3 @@ class TestIcalImportDX(unittest.TestCase):
         self.assertNotEqual(desc21, desc22)
         self.assertTrue(start21 < start22)
         self.assertTrue(end21 < end22)
-
-
-class TestIcalImportAT(TestIcalImportDX):
-    layer = PAEventAT_FUNCTIONAL_TESTING
-    event_type = 'Event'
